Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-pages.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIgor Wiedler <iwiedler@gitlab.com>2020-04-30 18:41:24 +0300
committerIgor Wiedler <iwiedler@gitlab.com>2020-04-30 18:41:24 +0300
commit76dc097b972fb9415b37b04b44cb54ca91811cb6 (patch)
tree38bf92a3e222df8cdce274785ab3e754a7a801b2 /app_config.go
parent22cadaef88074326535e49fb0dc2d345619408da (diff)
change back to internal-gitlab-server as per @@vshushlin
Diffstat (limited to 'app_config.go')
-rw-r--r--app_config.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/app_config.go b/app_config.go
index cbaed36f..5d481bb6 100644
--- a/app_config.go
+++ b/app_config.go
@@ -29,7 +29,7 @@ type appConfig struct {
StoreSecret string
GitLabServer string
- GitLabAPIServer string
+ InternalGitLabServer string
GitLabAPISecretKey []byte
GitlabClientHTTPTimeout time.Duration
GitlabJWTTokenExpiration time.Duration
@@ -41,9 +41,9 @@ type appConfig struct {
CustomHeaders []string
}
-// GitlabAPIServerURL returns URL to a GitLab instance.
-func (config appConfig) GitlabAPIServerURL() string {
- return config.GitLabAPIServer
+// InternalGitLabServerURL returns URL to a GitLab instance.
+func (config appConfig) InternalGitLabServerURL() string {
+ return config.InternalGitLabServer
}
// GitlabClientSecret returns GitLab server access token.